package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcContractWork;
import com.ruoyi.oa.service.ICmcContractWorkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc合同内容Controller
 * 
 * @author cmc
 * @date 2024-04-19
 */
@RestController
@RequestMapping("/oa/contractWork")
public class CmcContractWorkController extends BaseController
{
    @Autowired
    private ICmcContractWorkService cmcContractWorkService;

    /**
     * 查询cmc合同内容列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcContractWork cmcContractWork)
    {
        startPage();
        List<CmcContractWork> list = cmcContractWorkService.selectCmcContractWorkList(cmcContractWork);
        return getDataTable(list);
    }

    /**
     * 导出cmc合同内容列表
     */
    @Log(title = "cmc合同内容", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcContractWork cmcContractWork)
    {
        List<CmcContractWork> list = cmcContractWorkService.selectCmcContractWorkList(cmcContractWork);
        ExcelUtil<CmcContractWork> util = new ExcelUtil<CmcContractWork>(CmcContractWork.class);
        util.exportExcel(response, list, "cmc合同内容数据");
    }

    /**
     * 获取cmc合同内容详细信息
     */
    @GetMapping(value = "/{contractId}")
    public AjaxResult getInfo(@PathVariable("contractId") String contractId)
    {
        return success(cmcContractWorkService.selectCmcContractWorkByContractId(contractId));
    }

    /**
     * 新增cmc合同内容
     */
    @Log(title = "cmc合同内容", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcContractWork cmcContractWork)
    {
        return toAjax(cmcContractWorkService.insertCmcContractWork(cmcContractWork));
    }

    /**
     * 修改cmc合同内容
     */
    @Log(title = "cmc合同内容", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcContractWork cmcContractWork)
    {
        return toAjax(cmcContractWorkService.updateCmcContractWork(cmcContractWork));
    }

    /**
     * 删除cmc合同内容
     */
    @Log(title = "cmc合同内容", businessType = BusinessType.DELETE)
	@DeleteMapping("/{contractIds}")
    public AjaxResult remove(@PathVariable String[] contractIds)
    {
        return success(cmcContractWorkService.deleteCmcContractWorkByContractIds(contractIds));
    }
}
